import csv
import numpy as np
from itertools import takewhile
from scipy.stats import normaltest, wilcoxon

reader = csv.reader(open('ml_results.tsv'), delimiter='\t')
classifiers = reader.next()[1:-4]
their_results = {row[0]: {classifier: float(result) if result != '--' else np.nan
                          for classifier, result in zip(classifiers, row[1:-4])}
                 for row in takewhile(lambda row: row[0] != '', reader)}

get_results = lambda classifier: np.array([their_results[benchmark][classifier] 
                                           for benchmark in their_results])

for classifier in 'parRF_caret', 'rf_caret':
    a = get_results(classifier) 
    b = get_results('svm_C')
    mask = ~np.isnan(a) & ~np.isnan(b)
    a = a[mask]
    b = b[mask]
    diff = a - b
    positive_sum = diff[diff > 0].sum()
    negative_sum = -diff[diff < 0].sum()
    mean_diff = (positive_sum - negative_sum) / float(len(diff))
    print '{} vs svm_C: positive sum = {}, negative sum = {}, num benchmarks = {}, ' \
    	  'mean difference = {:.0g}, Wilcoxon p = {}'.format(
    	  	classifier, positive_sum, negative_sum, len(diff), mean_diff, wilcoxon(a, b)[1])