import csv
import numpy as np
from itertools import takewhile, chain
from scipy.stats import spearmanr

reader = csv.reader(open('ml_results.tsv'), delimiter='\t')
classifiers = reader.next()[1:-4]
their_results = {row[0]: {classifier: float(result) if result != '--' else np.nan
                          for classifier, result in zip(classifiers, row[1:-4])}
                 for row in takewhile(lambda row: row[0] != '', reader)}

top_8 = {classifier: np.array([their_results[benchmark][classifier] for benchmark in their_results])
         for classifier in ('parRF_caret', 'rf_caret', 'svm_C', 'svmPoly_caret', 'rforest_R',
                            'elm_kernel_matlab', 'svmRadialCost_caret', 'svmRadial_caret')}

# Exclude classifiers unsuccessfully run by any of the 8 (nan_mask)

nan_mask = np.zeros(len(their_results), dtype=bool)
for result in top_8.itervalues():
    nan_mask |= np.isnan(result)

old_results = [np.nanmean(result) for result in top_8.itervalues()]
new_results = [result[~nan_mask].mean() for result in top_8.itervalues()]
nums_nan = [np.isnan(result).sum() for result in top_8.itervalues()]

for rank, (classifier, old_result, new_result, num_nan) in enumerate(sorted(
        zip(top_8, old_results, new_results, nums_nan), key=lambda x: -x[2])):
    print r'{} & {} & {:.2f} & {:.2f} & {} \\\hline'.format(
        rank + 1, classifier, old_result, new_result, num_nan)
