import csv
import numpy as np
from itertools import takewhile
from scipy.stats import normaltest

reader = csv.reader(open('ml_results.tsv'), delimiter='\t')
classifiers = reader.next()[1:-4]
their_results = {row[0]: {classifier: float(result) if result != '--' else np.nan
                          for classifier, result in zip(classifiers, row[1:-4])}
                 for row in takewhile(lambda row: row[0] != '', reader)}

get_results = lambda classifier: np.array([their_results[benchmark][classifier] 
                                           for benchmark in their_results])

for classifier in ('elm_kernel_matlab', 'rf_caret', 'rforest_R', 
                   'svm_C', 'svmRadialCost_caret', 'svmPoly_caret', 
                   'svmRadial_caret', 'avNNet_caret', 'C5.0_caret'):
    diff = get_results('parRF_caret') - get_results(classifier)
    diff = diff[~np.isnan(diff)]
    print '{}\t{:.0g}'.format(classifier, normaltest(diff)[1])